@@ -3,7 +3,7 @@
 
 import { Http2ServerRequest, Http2ServerResponse } from 'http2'
 
-export function cors(req: Http2ServerRequest, res: Http2ServerResponse): void {
+export function cors(req: Http2ServerRequest, res: Http2ServerResponse): boolean {
     if (process.env.NODE_ENV !== 'production') {
         if (req.headers['origin']) {
             res.setHeader('Access-Control-Allow-Origin', req.headers['origin'])
@@ -19,7 +19,8 @@ export function cors(req: Http2ServerRequest, res: Http2ServerResponse): void {
                     res.setHeader('Access-Control-Allow-Headers', req.headers['access-control-request-headers'])
                 }
                 res.writeHead(200).end()
-                return
+                return true
         }
     }
+    return false
 }
