@@ -59,12 +59,11 @@ export async function loginCallback(req: Http2ServerRequest, res: Http2ServerRes
                 location: process.env.FRONTEND_URL,
             }
             res.writeHead(302, headers).end()
-            return
         } else {
-            return respondInternalServerError(req, res)
+            respondInternalServerError(req, res)
         }
     } else {
-        return respondInternalServerError(req, res)
+        respondInternalServerError(req, res)
     }
 }
 
