@@ -1,5 +1,5 @@
 /* Copyright Contributors to the Open Cluster Management project */
-import { AcmErrorBoundary, AcmPageContent, AcmPage, AcmPageHeader } from '@open-cluster-management/ui-components'
+import { AcmErrorBoundary, AcmPageContent, AcmPage, AcmPageHeader } from '@stolostron/ui-components'
 import { PageSection } from '@patternfly/react-core'
 import Handlebars from 'handlebars'
 import { get, keyBy } from 'lodash'
@@ -19,7 +19,7 @@ import { NavigationPath } from '../../../../../NavigationPath'
 import { useCanJoinClusterSets, useMustJoinClusterSet } from '../../ClusterSets/components/useCanJoinClusterSets'
 // template/data
 import { getControlData } from './controlData/ControlData'
-import { setAvailableConnections, setAvailableTemplates } from './controlData/ControlDataHelpers'
+import { setAvailableConnections, setAvailableTemplates, arrayItemHasKey } from './controlData/ControlDataHelpers'
 import './style.css'
 import hiveTemplate from './templates/hive-template.hbs'
 import endpointTemplate from './templates/endpoints.hbs'
@@ -248,8 +248,8 @@ export default function CreateClusterPage() {
     //compile templates
     const template = Handlebars.compile(hiveTemplate)
     Handlebars.registerPartial('endpoints', Handlebars.compile(endpointTemplate))
-
-    // if openned from bma page, pass selected bma's to editor
+    Handlebars.registerHelper('arrayItemHasKey', arrayItemHasKey)
+    // if opened from bma page, pass selected bma's to editor
     const urlParams = new URLSearchParams(location.search.substring(1))
     const bmasParam = urlParams.get('bmas')
     const requestedUIDs = bmasParam ? bmasParam.split(',') : []
