@@ -14,6 +14,7 @@ import {
     getWorkerName,
     isHidden_lt_OCP48,
     isHidden_SNO,
+    onChangeConnection,
     onChangeSNO,
     addSnoText,
 } from './ControlDataHelpers'
@@ -268,6 +269,7 @@ const controlDataGCP = [
             required: true,
         },
         available: [],
+        onSelect: onChangeConnection,
         prompts: CREATE_CLOUD_CONNECTION,
     },
     ...clusterDetailsControlData,
