@@ -75,6 +75,14 @@ export const getWorkerName = (control) => {
     return `Worker pool ${grpNum + 1}`
 }
 
+export function getOSTNetworkingControlData() {
+    // Kuryr should only be available for Openstack
+    const networkData = _.cloneDeep(networkingControlData)
+    const modifiedData = networkData.find((object) => object.id == 'networkType')
+    modifiedData.available.push('Kuryr')
+    return networkData
+}
+
 export const setAvailableOCPImages = (provider, control, result) => {
     const { loading } = result
     const { data } = result
@@ -182,6 +190,47 @@ export const setAvailableConnections = (control, secrets) => {
     control.available = connections.map((secret) => secret.metadata.name)
 }
 
+export const onChangeConnection = (control, controlData) => {
+    const { active, availableMap = {} } = control
+    const replacements = _.get(availableMap[active], 'replacements')
+    if (replacements) {
+        controlData.forEach((control) => {
+            switch (control.id) {
+                case 'hasProxy':
+                    control.active = !!replacements['httpProxy']
+                    break
+                case 'isDisconnected':
+                    control.active = !!replacements['imageContentSources']
+                    break
+                default:
+                    if (replacements[control.id]) {
+                        switch (control.type) {
+                            case 'values':
+                                control.active = replacements[control.id].split(',')
+                                break
+                            default:
+                                control.active = replacements[control.id]
+                                break
+                        }
+                        control.disabled = false
+                        if (control.id === 'disconnectedAdditionalTrustBundle') {
+                        }
+                    }
+                    break
+            }
+        })
+    }
+    setTimeout(() => {
+        const control = controlData.find(({ id }) => {
+            return id === 'disconnectedAdditionalTrustBundle'
+        })
+        if (control) {
+            control.active = replacements['additionalTrustBundle']
+            control.disabled = !control.active
+        }
+    })
+}
+
 export const setAvailableTemplates = (control, templates) => {
     control.available = templates.map((template) => template.metadata.name)
 }
@@ -407,6 +456,21 @@ export const isHidden_lt_OCP48 = (control, controlData) => {
     return true
 }
 
+export const isHidden_gt_OCP46 = (control, controlData) => {
+    const singleNodeFeatureFlag = controlData.find(({ id }) => id === 'singleNodeFeatureFlag')
+    const imageSet = controlData.find(({ id }) => id === 'imageSet')
+    if (
+        singleNodeFeatureFlag &&
+        singleNodeFeatureFlag.active &&
+        imageSet &&
+        imageSet.active &&
+        imageSet.active.includes('release:4.6')
+    ) {
+        return false
+    }
+    return true
+}
+
 export const isHidden_SNO = (control, controlData) => {
     const singleNode = controlData.find(({ id }) => id === 'singleNode')
     return singleNode && singleNode.active && !isHidden_lt_OCP48(control, controlData)
@@ -429,3 +493,7 @@ export const addSnoText = (controlData) => {
     const poolControlData = masterPool.controlData.find((object) => object.id == 'masterPool')
     poolControlData.info = 'creation.ocp.node.controlplane.pool.info.sno_enabled'
 }
+
+export const arrayItemHasKey = (options, key) => {
+    return options && options.some((o) => o[key])
+}
