@@ -7,7 +7,7 @@ var InventoryLoadError = function InventoryLoadError(_ref) {
       props = _objectWithoutProperties(_ref, ["component"]);
 
   useEffect(function () {
-    console.error("Unable to load inventory component. Failed to load ".concat(component, "."), props);
+    console.error("Unable to load iventory component. Failed to load ".concat(component, "."), props);
   }, []);
   return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("h1", null, "Unable to load inventory component"), /*#__PURE__*/React.createElement("h2", null, "Failed to load ", component), /*#__PURE__*/React.createElement("code", null, "More info can be found in browser console output."));
 };
