@@ -125,17 +125,6 @@ async function claimJWT(label, jwt) {
 }
 
 function getKeystore(jwks) {
-  if (!isPlainObject(jwks) || !Array.isArray(jwks.keys) || jwks.keys.some((k) => !isPlainObject(k) || !('kty' in k))) {
-    throw new TypeError('jwks must be a JSON Web Key Set formatted object');
-  }
-
-  // eslint-disable-next-line no-restricted-syntax
-  for (const jwk of jwks.keys) {
-    if (jwk.kid === undefined) {
-      jwk.kid = `DONOTUSE.${random()}`;
-    }
-  }
-
   const keystore = jose.JWKS.asKeyStore(jwks);
   if (keystore.all().some((key) => key.type !== 'private')) {
     throw new TypeError('jwks must only contain private keys');
@@ -1024,9 +1013,8 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
       method,
       headers,
       body,
+      tokenType = accessToken instanceof TokenSet ? accessToken.token_type : 'Bearer',
       DPoP,
-      // eslint-disable-next-line no-nested-ternary
-      tokenType = DPoP ? 'DPoP' : accessToken instanceof TokenSet ? accessToken.token_type : 'Bearer',
     } = {},
   ) {
     if (accessToken instanceof TokenSet) {
@@ -1051,7 +1039,7 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
       responseType: 'buffer',
       method,
       url: resourceUrl,
-    }, { accessToken, mTLS, DPoP });
+    }, { mTLS, DPoP });
   }
 
   /**
@@ -1437,12 +1425,6 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
     if (jwks !== undefined && !(metadata.jwks || metadata.jwks_uri)) {
       const keystore = getKeystore.call(this, jwks);
       metadata.jwks = keystore.toJWKS(false);
-      // eslint-disable-next-line no-restricted-syntax
-      for (const jwk of metadata.jwks.keys) {
-        if (jwk.kid.startsWith('DONOTUSE.')) {
-          delete jwk.kid;
-        }
-      }
     }
 
     const response = await request.call(this, {
@@ -1542,7 +1524,7 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
 
       signed = jose.JWS.sign(payload, key, {
         ...header,
-        kid: symmetric || key.kid.startsWith('DONOTUSE.') ? undefined : key.kid,
+        kid: symmetric ? undefined : key.kid,
       });
     }
 
@@ -1568,57 +1550,6 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
     });
   }
 
-  /**
-   * @name pushedAuthorizationRequest
-   * @api public
-   */
-  async pushedAuthorizationRequest(params = {}, { clientAssertionPayload } = {}) {
-    assertIssuerConfiguration(this.issuer, 'pushed_authorization_request_endpoint');
-
-    const body = {
-      ...('request' in params ? params : authorizationParams.call(this, params)),
-      client_id: this.client_id,
-    };
-
-    const response = await authenticatedPost.call(
-      this,
-      'pushed_authorization_request',
-      {
-        responseType: 'json',
-        form: body,
-      },
-      { clientAssertionPayload, endpointAuthMethod: 'token' },
-    );
-    const responseBody = processResponse(response, { statusCode: 201 });
-
-    if (!('expires_in' in responseBody)) {
-      throw new RPError({
-        message: 'expected expires_in in Pushed Authorization Successful Response',
-        response,
-      });
-    }
-    if (typeof responseBody.expires_in !== 'number') {
-      throw new RPError({
-        message: 'invalid expires_in value in Pushed Authorization Successful Response',
-        response,
-      });
-    }
-    if (!('request_uri' in responseBody)) {
-      throw new RPError({
-        message: 'expected request_uri in Pushed Authorization Successful Response',
-        response,
-      });
-    }
-    if (typeof responseBody.request_uri !== 'string') {
-      throw new RPError({
-        message: 'invalid request_uri value in Pushed Authorization Successful Response',
-        response,
-      });
-    }
-
-    return responseBody;
-  }
-
   /**
    * @name issuer
    * @api public
@@ -1677,7 +1608,7 @@ Object.defineProperty(BaseClient.prototype, 'validateJARM', {
  * @name dpopProof
  * @api private
  */
-function dpopProof(payload, jwk, accessToken) {
+function dpopProof(payload, jwk) {
   if (!isPlainObject(payload)) {
     throw new TypeError('payload must be a plain object');
   }
@@ -1704,7 +1635,6 @@ function dpopProof(payload, jwk, accessToken) {
   return jose.JWS.sign({
     iat: now(),
     jti: random(),
-    ath: accessToken ? base64url.encode(crypto.createHash('sha256').update(accessToken).digest()) : undefined,
     ...payload,
   }, jwk, {
     alg,
@@ -1718,7 +1648,7 @@ Object.defineProperty(BaseClient.prototype, 'dpopProof', {
   configurable: true,
   value(...args) {
     process.emitWarning(
-      'The DPoP APIs implements an IETF draft (https://www.ietf.org/archive/id/draft-ietf-oauth-dpop-03.html). Breaking draft implementations are included as minor versions of the openid-client library, therefore, the ~ semver operator should be used and close attention be payed to library changelog as well as the drafts themselves.',
+      'The DPoP APIs implements an IETF draft. Breaking draft implementations are included as minor versions of the openid-client library, therefore, the ~ semver operator should be used and close attention be payed to library changelog as well as the drafts themselves.',
       'DraftWarning',
     );
     Object.defineProperty(BaseClient.prototype, 'dpopProof', {
@@ -1730,4 +1660,72 @@ Object.defineProperty(BaseClient.prototype, 'dpopProof', {
   },
 });
 
+/**
+ * @name pushedAuthorizationRequest
+ * @api public
+ */
+async function pushedAuthorizationRequest(params = {}, { clientAssertionPayload } = {}) {
+  assertIssuerConfiguration(this.issuer, 'pushed_authorization_request_endpoint');
+
+  const body = {
+    ...('request' in params ? params : authorizationParams.call(this, params)),
+    client_id: this.client_id,
+  };
+
+  const response = await authenticatedPost.call(
+    this,
+    'pushed_authorization_request',
+    {
+      responseType: 'json',
+      form: body,
+    },
+    { clientAssertionPayload, endpointAuthMethod: 'token' },
+  );
+  const responseBody = processResponse(response, { statusCode: 201 });
+
+  if (!('expires_in' in responseBody)) {
+    throw new RPError({
+      message: 'expected expires_in in Pushed Authorization Successful Response',
+      response,
+    });
+  }
+  if (typeof responseBody.expires_in !== 'number') {
+    throw new RPError({
+      message: 'invalid expires_in value in Pushed Authorization Successful Response',
+      response,
+    });
+  }
+  if (!('request_uri' in responseBody)) {
+    throw new RPError({
+      message: 'expected request_uri in Pushed Authorization Successful Response',
+      response,
+    });
+  }
+  if (typeof responseBody.request_uri !== 'string') {
+    throw new RPError({
+      message: 'invalid request_uri value in Pushed Authorization Successful Response',
+      response,
+    });
+  }
+
+  return responseBody;
+}
+
+Object.defineProperty(BaseClient.prototype, 'pushedAuthorizationRequest', {
+  enumerable: true,
+  configurable: true,
+  value(...args) {
+    process.emitWarning(
+      'The Pushed Authorization Requests APIs implements an IETF draft. Breaking draft implementations are included as minor versions of the openid-client library, therefore, the ~ semver operator should be used and close attention be payed to library changelog as well as the drafts themselves.',
+      'DraftWarning',
+    );
+    Object.defineProperty(BaseClient.prototype, 'pushedAuthorizationRequest', {
+      enumerable: true,
+      configurable: true,
+      value: pushedAuthorizationRequest,
+    });
+    return this.pushedAuthorizationRequest(...args);
+  },
+});
+
 module.exports.BaseClient = BaseClient;
