@@ -7,7 +7,6 @@
 
 const docsUrl = require('../util/docsUrl');
 const linkComponentsUtil = require('../util/linkComponents');
-const report = require('../util/report');
 
 // ------------------------------------------------------------------------------
 // Rule Definition
@@ -96,11 +95,6 @@ function hasSecureRel(node, allowReferrer, warnOnSpreadAttributes, spreadAttribu
   return allowReferrer && tags && tags.indexOf('noopener') >= 0;
 }
 
-const messages = {
-  noTargetBlankWithoutNoreferrer: 'Using target="_blank" without rel="noreferrer" (which implies rel="noopener") is a security risk in older browsers: see https://mathiasbynens.github.io/rel-noopener/#recommendations',
-  noTargetBlankWithoutNoopener: 'Using target="_blank" without rel="noreferrer" or rel="noopener" (the former implies the latter and is preferred due to wider support) is a security risk: see https://mathiasbynens.github.io/rel-noopener/#recommendations'
-};
-
 module.exports = {
   meta: {
     fixable: 'code',
@@ -111,7 +105,10 @@ module.exports = {
       url: docsUrl('jsx-no-target-blank')
     },
 
-    messages,
+    messages: {
+      noTargetBlank: 'Using target="_blank" without rel="noreferrer" '
+        + 'is a security risk: see https://html.spec.whatwg.org/multipage/links.html#link-type-noopener'
+    },
 
     schema: [{
       type: 'object',
@@ -174,9 +171,9 @@ module.exports = {
           const hasDangerousLink = hasExternalLink(node, linkAttribute, warnOnSpreadAttributes, spreadAttributeIndex)
             || (enforceDynamicLinks === 'always' && hasDynamicLink(node, linkAttribute));
           if (hasDangerousLink && !hasSecureRel(node, allowReferrer, warnOnSpreadAttributes, spreadAttributeIndex)) {
-            const messageId = allowReferrer ? 'noTargetBlankWithoutNoopener' : 'noTargetBlankWithoutNoreferrer';
-            report(context, messages[messageId], messageId, {
+            context.report({
               node,
+              messageId: 'noTargetBlank',
               fix(fixer) {
                 // eslint 5 uses `node.attributes`; eslint 6+ uses `node.parent.attributes`
                 const nodeWithAttrs = node.parent.attributes ? node.parent : node;
@@ -246,9 +243,9 @@ module.exports = {
             hasExternalLink(node, formAttribute)
             || (enforceDynamicLinks === 'always' && hasDynamicLink(node, formAttribute))
           ) {
-            const messageId = allowReferrer ? 'noTargetBlankWithoutNoopener' : 'noTargetBlankWithoutNoreferrer';
-            report(context, messages[messageId], messageId, {
-              node
+            context.report({
+              node,
+              messageId: 'noTargetBlank'
             });
           }
         }
