@@ -1,5 +1,4 @@
-const base64url = require('base64url');
-
+const base64url = require('./helpers/base64url');
 const now = require('./helpers/unix_timestamp');
 
 class TokenSet {
