@@ -2,13 +2,14 @@ import * as React from 'react';
 import styles from '@patternfly/react-styles/css/components/DualListSelector/dual-list-selector';
 import { css } from '@patternfly/react-styles';
 import { Button, ButtonVariant } from '../Button';
-import AngleDoubleLeftIcon from '@patternfly/react-icons/dist/js/icons/angle-double-left-icon';
-import AngleLeftIcon from '@patternfly/react-icons/dist/js/icons/angle-left-icon';
-import AngleDoubleRightIcon from '@patternfly/react-icons/dist/js/icons/angle-double-right-icon';
-import AngleRightIcon from '@patternfly/react-icons/dist/js/icons/angle-right-icon';
+import AngleDoubleLeftIcon from '@patternfly/react-icons/dist/esm/icons/angle-double-left-icon';
+import AngleLeftIcon from '@patternfly/react-icons/dist/esm/icons/angle-left-icon';
+import AngleDoubleRightIcon from '@patternfly/react-icons/dist/esm/icons/angle-double-right-icon';
+import AngleRightIcon from '@patternfly/react-icons/dist/esm/icons/angle-right-icon';
 import { DualListSelectorPane } from './DualListSelectorPane';
 import { getUniqueId, PickOptional } from '../../helpers';
 import { DualListSelectorTreeItemData } from './DualListSelectorTree';
+import { Tooltip } from '../Tooltip';
 import {
   flattenTree,
   flattenTreeWithFolders,
@@ -17,6 +18,8 @@ import {
   filterTreeItemsWithoutFolders,
   filterRestTreeItems
 } from './treeUtils';
+import { canUseDOM } from '../../helpers/util';
+import { handleArrows } from '../../helpers';
 export interface DualListSelectorProps {
   /** Additional classes applied to the dual list selector. */
   className?: string;
@@ -42,20 +45,36 @@ export interface DualListSelectorProps {
   addSelected?: (newAvailableOptions: React.ReactNode[], newChosenOptions: React.ReactNode[]) => void;
   /** Accessible label for the add selected button */
   addSelectedAriaLabel?: string;
+  /** Tooltip content for the add selected button */
+  addSelectedTooltip?: React.ReactNode;
+  /** Additonal tooltip properties for the add selected tooltip */
+  addSelectedTooltipProps?: any;
   /** Callback fired every time options are chosen or removed */
   onListChange?: (newAvailableOptions: React.ReactNode[], newChosenOptions: React.ReactNode[]) => void;
   /** Optional callback for the add all button */
   addAll?: (newAvailableOptions: React.ReactNode[], newChosenOptions: React.ReactNode[]) => void;
   /** Accessible label for the add all button */
   addAllAriaLabel?: string;
+  /** Tooltip content for the add all button */
+  addAllTooltip?: React.ReactNode;
+  /** Additonal tooltip properties for the add all tooltip */
+  addAllTooltipProps?: any;
   /** Optional callback for the remove selected button */
   removeSelected?: (newAvailableOptions: React.ReactNode[], newChosenOptions: React.ReactNode[]) => void;
   /** Accessible label for the remove selected button */
   removeSelectedAriaLabel?: string;
+  /** Tooltip content for the remove selected button */
+  removeSelectedTooltip?: React.ReactNode;
+  /** Additonal tooltip properties for the remove selected tooltip  */
+  removeSelectedTooltipProps?: any;
   /** Optional callback for the remove all button */
   removeAll?: (newAvailableOptions: React.ReactNode[], newChosenOptions: React.ReactNode[]) => void;
   /** Accessible label for the remove all button */
   removeAllAriaLabel?: string;
+  /** Tooltip content for the remove all button */
+  removeAllTooltip?: React.ReactNode;
+  /** Additonal tooltip properties for the remove all tooltip */
+  removeAllTooltipProps?: any;
   /** Optional callback fired when an option is selected */
   onOptionSelect?: (e: React.MouseEvent | React.ChangeEvent) => void;
   /** Optional callback fired when an option is checked */
@@ -69,8 +88,12 @@ export interface DualListSelectorProps {
   isSearchable?: boolean;
   /** Accessible label for the search input on the available options pane. */
   availableOptionsSearchAriaLabel?: string;
+  /** A callback for when the search input value for available options changes. */
+  onAvailableOptionsSearchInputChanged?: (value: string, event: React.FormEvent<HTMLInputElement>) => void;
   /** Accessible label for the search input on the chosen options pane. */
   chosenOptionsSearchAriaLabel?: string;
+  /** A callback for when the search input value for chosen options changes. */
+  onChosenOptionsSearchInputChanged?: (value: string, event: React.FormEvent<HTMLInputElement>) => void;
   /** Optional filter function for custom filtering based on search string. */
   filterOption?: (option: React.ReactNode, input: string) => boolean;
   /** Id of the dual list selector. */
@@ -82,17 +105,25 @@ export interface DualListSelectorProps {
 interface DualListSelectorState {
   availableOptions: React.ReactNode[];
   availableOptionsSelected: number[];
+  availableFilteredOptions: React.ReactNode[];
   chosenOptions: React.ReactNode[];
   chosenOptionsSelected: number[];
+  chosenFilteredOptions: React.ReactNode[];
   availableTreeOptionsSelected: string[];
+  availableTreeFilteredOptions: string[];
   chosenTreeOptionsSelected: string[];
   availableTreeOptionsChecked: string[];
   chosenTreeOptionsChecked: string[];
+  chosenTreeFilteredOptions: string[];
 }
 
 export class DualListSelector extends React.Component<DualListSelectorProps, DualListSelectorState> {
   static displayName = 'DualListSelector';
   private controlsEl = React.createRef<HTMLDivElement>();
+  private addAllButtonRef = React.createRef<HTMLButtonElement>();
+  private addSelectedButtonRef = React.createRef<HTMLButtonElement>();
+  private removeSelectedButtonRef = React.createRef<HTMLButtonElement>();
+  private removeAllButtonRef = React.createRef<HTMLButtonElement>();
   static defaultProps: PickOptional<DualListSelectorProps> = {
     availableOptions: [] as React.ReactNode[],
     availableOptionsTitle: 'Available options',
@@ -107,15 +138,20 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
     removeSelectedAriaLabel: 'Remove selected',
     removeAllAriaLabel: 'Remove all'
   };
-  private originalCopy = this.props.availableOptions;
+  private originalAvailableCopy = this.props.availableOptions;
+  private originalChosenCopy = this.props.chosenOptions;
 
   constructor(props: DualListSelectorProps) {
     super(props);
     this.state = {
       availableOptions: [...this.props.availableOptions],
       availableOptionsSelected: [],
+      availableFilteredOptions: null,
+      availableTreeFilteredOptions: null,
       chosenOptions: [...this.props.chosenOptions],
       chosenOptionsSelected: [],
+      chosenFilteredOptions: null,
+      chosenTreeFilteredOptions: null,
       availableTreeOptionsSelected: [],
       chosenTreeOptionsSelected: [],
       availableTreeOptionsChecked: [],
@@ -135,42 +171,103 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
     }
   }
 
-  addAll = () => {
-    this.setState(prevState => {
-      let newChosen = [] as React.ReactNode[];
-      if (this.props.isTree) {
-        newChosen = this.originalCopy;
-      } else {
-        newChosen = [...prevState.chosenOptions, ...prevState.availableOptions];
+  onFilterUpdate = (newFilteredOptions: React.ReactNode[], paneType: string, isSearchReset: boolean) => {
+    const { isTree } = this.props;
+    if (paneType === 'available') {
+      if (isSearchReset) {
+        this.setState({
+          availableFilteredOptions: null,
+          availableTreeFilteredOptions: null
+        });
+        return;
       }
-      this.props.addAll && this.props.addAll([], newChosen);
-      this.props.onListChange && this.props.onListChange([], newChosen);
+      if (isTree) {
+        this.setState({
+          availableTreeFilteredOptions: flattenTreeWithFolders(newFilteredOptions as DualListSelectorTreeItemData[])
+        });
+      } else {
+        this.setState({
+          availableFilteredOptions: newFilteredOptions as React.ReactNode[]
+        });
+      }
+    } else if (paneType === 'chosen') {
+      if (isSearchReset) {
+        this.setState({
+          chosenFilteredOptions: null,
+          chosenTreeFilteredOptions: null
+        });
+        return;
+      }
+      if (isTree) {
+        this.setState({
+          chosenTreeFilteredOptions: flattenTreeWithFolders(newFilteredOptions as DualListSelectorTreeItemData[])
+        });
+      } else {
+        this.setState({
+          chosenFilteredOptions: newFilteredOptions as React.ReactNode[]
+        });
+      }
+    }
+  };
+
+  addAllVisible = () => {
+    this.setState(prevState => {
+      const itemsToRemove = [] as React.ReactNode[];
+      const newAvailable = [] as React.ReactNode[];
+      const movedOptions = prevState.availableFilteredOptions || prevState.availableOptions;
+      prevState.availableOptions.forEach(value => {
+        if (movedOptions.indexOf(value) !== -1) {
+          itemsToRemove.push(value);
+        } else {
+          newAvailable.push(value);
+        }
+      });
+
+      const newChosen = [...prevState.chosenOptions, ...itemsToRemove];
+      this.props.addAll && this.props.addAll(newAvailable, newChosen);
+      this.props.onListChange && this.props.onListChange(newAvailable, newChosen);
 
       return {
-        availableOptions: [],
-        availableOptionsSelected: [],
         chosenOptions: newChosen,
-        chosenOptionsSelected: []
+        availableOptions: newAvailable,
+        chosenOptionsSelected: [],
+        availableOptionsSelected: []
       };
     });
   };
 
-  removeAll = () => {
+  addAllTreeVisible = () => {
     this.setState(prevState => {
-      let newAvailable = [] as React.ReactNode[];
-      if (this.props.isTree) {
-        newAvailable = this.originalCopy;
-      } else {
-        newAvailable = [...prevState.chosenOptions, ...prevState.availableOptions];
-      }
-      this.props.removeAll && this.props.removeAll(newAvailable, []);
-      this.props.onListChange && this.props.onListChange(newAvailable, []);
+      const movedOptions =
+        prevState.availableTreeFilteredOptions ||
+        flattenTreeWithFolders(prevState.availableOptions as DualListSelectorTreeItemData[]);
+
+      const newAvailable = prevState.availableOptions
+        .map(opt => Object.assign({}, opt))
+        .filter(item => filterRestTreeItems(item as DualListSelectorTreeItemData, movedOptions));
+
+      const currChosen = flattenTree(prevState.chosenOptions as DualListSelectorTreeItemData[]);
+      const nextChosenOptions = currChosen.concat(movedOptions);
+
+      const allOptions = (this.originalAvailableCopy as DualListSelectorTreeItemData[]).concat(
+        this.originalChosenCopy as DualListSelectorTreeItemData[]
+      );
+      const newChosen = allOptions
+        .map(opt => Object.assign({}, opt))
+        .filter(item => filterTreeItemsWithoutFolders(item as DualListSelectorTreeItemData, nextChosenOptions));
+
+      this.props.addAll && this.props.addAll(newAvailable, newChosen);
+      this.props.onListChange && this.props.onListChange(newAvailable, newChosen);
 
       return {
+        chosenOptions: newChosen,
+        chosenFilteredOptions: newChosen,
         availableOptions: newAvailable,
-        availableOptionsSelected: [],
-        chosenOptions: [],
-        chosenOptionsSelected: []
+        availableFilteredOptions: newAvailable,
+        availableTreeOptionsSelected: [],
+        chosenTreeOptionsSelected: [],
+        availableTreeOptionsChecked: [],
+        chosenTreeOptionsChecked: []
       };
     });
   };
@@ -212,7 +309,10 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
       // Get next chosen options from current + new nodes and remap from base
       const currChosen = flattenTree(prevState.chosenOptions as DualListSelectorTreeItemData[]);
       const nextChosenOptions = currChosen.concat(prevState.availableTreeOptionsSelected);
-      const newChosen = (this.originalCopy as DualListSelectorTreeItemData[])
+      const allOptions = (this.originalAvailableCopy as DualListSelectorTreeItemData[]).concat(
+        this.originalChosenCopy as DualListSelectorTreeItemData[]
+      );
+      const newChosen = allOptions
         .map(opt => Object.assign({}, opt))
         .filter(item => filterTreeItemsWithoutFolders(item as DualListSelectorTreeItemData, nextChosenOptions));
 
@@ -230,6 +330,65 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
     });
   };
 
+  removeAllVisible = () => {
+    this.setState(prevState => {
+      const itemsToRemove = [] as React.ReactNode[];
+      const newChosen = [] as React.ReactNode[];
+      const movedOptions = prevState.chosenFilteredOptions || prevState.chosenOptions;
+      prevState.chosenOptions.forEach(value => {
+        if (movedOptions.indexOf(value) !== -1) {
+          itemsToRemove.push(value);
+        } else {
+          newChosen.push(value);
+        }
+      });
+
+      const newAvailable = [...prevState.availableOptions, ...itemsToRemove];
+      this.props.removeAll && this.props.removeAll(newAvailable, newChosen);
+      this.props.onListChange && this.props.onListChange(newAvailable, newChosen);
+
+      return {
+        chosenOptions: newChosen,
+        availableOptions: newAvailable,
+        chosenOptionsSelected: [],
+        availableOptionsSelected: []
+      };
+    });
+  };
+
+  removeAllTreeVisible = () => {
+    this.setState(prevState => {
+      const movedOptions =
+        prevState.chosenTreeFilteredOptions ||
+        flattenTreeWithFolders(prevState.chosenOptions as DualListSelectorTreeItemData[]);
+
+      const newChosen = prevState.chosenOptions
+        .map(opt => Object.assign({}, opt))
+        .filter(item => filterRestTreeItems(item as DualListSelectorTreeItemData, movedOptions));
+      const currAvailable = flattenTree(prevState.availableOptions as DualListSelectorTreeItemData[]);
+      const nextAvailableOptions = currAvailable.concat(movedOptions);
+
+      const allOptions = (this.originalAvailableCopy as DualListSelectorTreeItemData[]).concat(
+        this.originalChosenCopy as DualListSelectorTreeItemData[]
+      );
+      const newAvailable = allOptions
+        .map(opt => Object.assign({}, opt))
+        .filter(item => filterTreeItemsWithoutFolders(item as DualListSelectorTreeItemData, nextAvailableOptions));
+
+      this.props.removeAll && this.props.removeAll(newAvailable, newChosen);
+      this.props.onListChange && this.props.onListChange(newAvailable, newChosen);
+
+      return {
+        chosenOptions: newChosen,
+        availableOptions: newAvailable,
+        availableTreeOptionsSelected: [],
+        chosenTreeOptionsSelected: [],
+        availableTreeOptionsChecked: [],
+        chosenTreeOptionsChecked: []
+      };
+    });
+  };
+
   removeSelected = () => {
     this.setState(prevState => {
       const itemsToRemove = [] as React.ReactNode[];
@@ -265,7 +424,11 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
       // Get next chosen options from current and remap from base
       const currAvailable = flattenTree(prevState.availableOptions as DualListSelectorTreeItemData[]);
       const nextAvailableOptions = currAvailable.concat(prevState.chosenTreeOptionsSelected);
-      const newAvailable = (this.originalCopy as DualListSelectorTreeItemData[])
+
+      const allOptions = (this.originalAvailableCopy as DualListSelectorTreeItemData[]).concat(
+        this.originalChosenCopy as DualListSelectorTreeItemData[]
+      );
+      const newAvailable = allOptions
         .map(opt => Object.assign({}, opt))
         .filter(item => filterTreeItemsWithoutFolders(item as DualListSelectorTreeItemData, nextAvailableOptions));
 
@@ -395,10 +558,32 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
     isChosen: boolean,
     itemData: DualListSelectorTreeItemData
   ) => {
+    const { availableOptions, availableTreeFilteredOptions, chosenOptions, chosenTreeFilteredOptions } = this.state;
     const checked = (evt as React.ChangeEvent<HTMLInputElement>).target.checked
       ? (evt as React.ChangeEvent<HTMLInputElement>).target.checked
       : isChecked;
-    const panelOptions = isChosen ? this.state.chosenOptions : this.state.availableOptions;
+    let panelOptions;
+    if (isChosen) {
+      if (chosenTreeFilteredOptions) {
+        panelOptions = chosenOptions
+          .map(opt => Object.assign({}, opt))
+          .filter(item =>
+            filterTreeItemsWithoutFolders(item as DualListSelectorTreeItemData, chosenTreeFilteredOptions)
+          );
+      } else {
+        panelOptions = chosenOptions;
+      }
+    } else {
+      if (availableTreeFilteredOptions) {
+        panelOptions = availableOptions
+          .map(opt => Object.assign({}, opt))
+          .filter(item =>
+            filterTreeItemsWithoutFolders(item as DualListSelectorTreeItemData, availableTreeFilteredOptions)
+          );
+      } else {
+        panelOptions = availableOptions;
+      }
+    }
     const checkedOptionTree = panelOptions
       .map(opt => Object.assign({}, opt))
       .filter(item => filterTreeItems(item as DualListSelectorTreeItemData, [itemData.id]));
@@ -432,51 +617,43 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
   };
 
   handleKeys = (event: KeyboardEvent) => {
-    const key = event.key;
-    let moveFocus = false;
-    let currentIndex = -1;
-    const controls = Array.from(this.controlsEl.current.getElementsByClassName('pf-c-button'));
-    if (['ArrowUp', 'ArrowDown', 'ArrowLeft', 'ArrowRight'].includes(event.key)) {
-      if (document.activeElement === this.controlsEl.current) {
-        currentIndex = 0;
-        while (
-          currentIndex < controls.length &&
-          currentIndex >= 0 &&
-          controls[currentIndex].classList.contains('pf-m-disabled')
-        ) {
-          currentIndex = currentIndex + 1;
-        }
-        moveFocus = true;
-        event.preventDefault();
-      } else {
-        controls.forEach((control, index) => {
-          if (document.activeElement === control) {
-            const increment = key === 'ArrowUp' || key === 'ArrowLeft' ? -1 : 1;
-            currentIndex = index + increment;
-            while (
-              currentIndex < controls.length &&
-              currentIndex >= 0 &&
-              controls[currentIndex].classList.contains('pf-m-disabled')
-            ) {
-              currentIndex = currentIndex + increment;
-            }
-            moveFocus = true;
-            event.preventDefault();
-          }
-        });
-      }
-    }
-    if (moveFocus && controls[currentIndex]) {
-      (controls[currentIndex] as HTMLElement).focus();
+    if (
+      !this.controlsEl.current ||
+      (this.controlsEl.current !== (event.target as HTMLElement).closest('.pf-c-dual-list-selector__controls') &&
+        !Array.from(this.controlsEl.current.getElementsByClassName('pf-c-dual-list-selector__controls')).includes(
+          (event.target as HTMLElement).closest('.pf-c-dual-list-selector__controls')
+        ))
+    ) {
+      return;
     }
+    event.stopImmediatePropagation();
+
+    const controls = Array.from(this.controlsEl.current.getElementsByTagName('BUTTON')).filter(
+      el => !el.classList.contains('pf-m-disabled')
+    );
+    const activeElement = document.activeElement;
+    handleArrows(
+      event,
+      controls,
+      (element: Element) => activeElement.contains(element),
+      (element: Element) => element,
+      undefined,
+      undefined,
+      true,
+      false
+    );
   };
 
   componentDidMount() {
-    window.addEventListener('keydown', this.handleKeys);
+    if (canUseDOM) {
+      window.addEventListener('keydown', this.handleKeys);
+    }
   }
 
   componentWillUnmount() {
-    window.removeEventListener('keydown', this.handleKeys);
+    if (canUseDOM) {
+      window.removeEventListener('keydown', this.handleKeys);
+    }
   }
 
   render() {
@@ -505,10 +682,20 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
       removeAll,
       addSelected,
       onListChange,
+      onAvailableOptionsSearchInputChanged,
+      onChosenOptionsSearchInputChanged,
       onOptionSelect,
       onOptionCheck,
       id,
       isTree,
+      addAllTooltip,
+      addAllTooltipProps,
+      addSelectedTooltip,
+      addSelectedTooltipProps,
+      removeAllTooltip,
+      removeAllTooltipProps,
+      removeSelectedTooltip,
+      removeSelectedTooltipProps,
       ...props
     } = this.props;
     const {
@@ -546,8 +733,10 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
       <div className={css(styles.dualListSelector, className)} id={id} {...props}>
         <DualListSelectorPane
           isSearchable={isSearchable}
+          onFilterUpdate={this.onFilterUpdate}
           searchInputAriaLabel={availableOptionsSearchAriaLabel}
           filterOption={filterOption}
+          onSearchInputChanged={onAvailableOptionsSearchInputChanged}
           status={availableOptionsStatusToDisplay}
           title={availableOptionsTitle}
           options={available}
@@ -564,18 +753,6 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
           ref={this.controlsEl}
           aria-label={controlsAriaLabel}
         >
-          <div className={css('pf-c-dual-list-selector__controls-item')}>
-            <Button
-              isDisabled={availableOptions.length === 0}
-              aria-disabled={availableOptions.length === 0}
-              variant={ButtonVariant.plain}
-              onClick={this.addAll}
-              aria-label={addAllAriaLabel}
-              tabIndex={-1}
-            >
-              <AngleDoubleRightIcon />
-            </Button>
-          </div>
           <div className={css('pf-c-dual-list-selector__controls-item')}>
             <Button
               isDisabled={isTree ? availableTreeOptionsSelected.length === 0 : availableOptionsSelected.length === 0}
@@ -584,9 +761,60 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
               onClick={isTree ? this.addTreeSelected : this.addSelected}
               aria-label={addSelectedAriaLabel}
               tabIndex={-1}
+              ref={this.addSelectedButtonRef}
             >
               <AngleRightIcon />
             </Button>
+            {addSelectedTooltip && (
+              <Tooltip
+                content={addSelectedTooltip}
+                position="right"
+                reference={this.addSelectedButtonRef}
+                {...addSelectedTooltipProps}
+              />
+            )}
+          </div>
+          <div className={css('pf-c-dual-list-selector__controls-item')}>
+            <Button
+              isDisabled={availableOptions.length === 0}
+              aria-disabled={availableOptions.length === 0}
+              variant={ButtonVariant.plain}
+              onClick={isTree ? this.addAllTreeVisible : this.addAllVisible}
+              aria-label={addAllAriaLabel}
+              tabIndex={-1}
+              ref={this.addAllButtonRef}
+            >
+              <AngleDoubleRightIcon />
+            </Button>
+            {addAllTooltip && (
+              <Tooltip
+                content={addAllTooltip}
+                position="left"
+                reference={this.addAllButtonRef}
+                {...addAllTooltipProps}
+              />
+            )}
+          </div>
+          <div className={css('pf-c-dual-list-selector__controls-item')}>
+            <Button
+              isDisabled={chosenOptions.length === 0}
+              aria-disabled={chosenOptions.length === 0}
+              variant={ButtonVariant.plain}
+              onClick={isTree ? this.removeAllTreeVisible : this.removeAllVisible}
+              aria-label={removeAllAriaLabel}
+              tabIndex={-1}
+              ref={this.removeAllButtonRef}
+            >
+              <AngleDoubleLeftIcon />
+            </Button>
+            {removeAllTooltip && (
+              <Tooltip
+                content={removeAllTooltip}
+                position="right"
+                reference={this.removeAllButtonRef}
+                {...removeAllTooltipProps}
+              />
+            )}
           </div>
           <div className={css('pf-c-dual-list-selector__controls-item')}>
             <Button
@@ -596,28 +824,27 @@ export class DualListSelector extends React.Component<DualListSelectorProps, Dua
               tabIndex={-1}
               isDisabled={isTree ? chosenTreeOptionsSelected.length === 0 : chosenOptionsSelected.length === 0}
               aria-disabled={isTree ? chosenTreeOptionsSelected.length === 0 : chosenOptionsSelected.length === 0}
+              ref={this.removeSelectedButtonRef}
             >
               <AngleLeftIcon />
             </Button>
-          </div>
-          <div className={css('pf-c-dual-list-selector__controls-item')}>
-            <Button
-              isDisabled={chosenOptions.length === 0}
-              aria-disabled={chosenOptions.length === 0}
-              variant={ButtonVariant.plain}
-              onClick={this.removeAll}
-              aria-label={removeAllAriaLabel}
-              tabIndex={-1}
-            >
-              <AngleDoubleLeftIcon />
-            </Button>
+            {removeSelectedTooltip && (
+              <Tooltip
+                content={removeSelectedTooltip}
+                position="left"
+                reference={this.removeSelectedButtonRef}
+                {...removeSelectedTooltipProps}
+              />
+            )}
           </div>
         </div>
         <DualListSelectorPane
           isChosen
           isSearchable={isSearchable}
+          onFilterUpdate={this.onFilterUpdate}
           searchInputAriaLabel={chosenOptionsSearchAriaLabel}
           filterOption={filterOption}
+          onSearchInputChanged={onChosenOptionsSearchInputChanged}
           title={chosenOptionsTitle}
           status={chosenOptionsStatusToDisplay}
           options={chosen}
